@@ -15,6 +15,7 @@
 
 #include <KAboutData>
 #include <KSharedConfig>
+#include <qprocess.h>
 
 class QQuickWindow;
 class KActionCollection;
@@ -45,10 +46,14 @@ protected:
 class Application : public QObject
 {
     Q_OBJECT
-    Q_PROPERTY(QAbstractItemModel *colorSchemesModel READ colorSchemesModel CONSTANT)
+    QML_SINGLETON
+    QML_NAMED_ELEMENT(HarunaApp)
 
 public:
     static Application *instance();
+    static Application *create(QQmlEngine *, QJSEngine *);
+
+    Q_PROPERTY(QAbstractItemModel *colorSchemesModel READ colorSchemesModel CONSTANT)
 
     Q_INVOKABLE bool urlExists(const QUrl &url);
     Q_INVOKABLE bool pathExists(const QString &url);
@@ -71,6 +76,7 @@ public:
     Q_INVOKABLE int qtMajorVersion();
     Q_INVOKABLE QString platformName();
     Q_INVOKABLE void raiseWindow();
+    Q_INVOKABLE bool isPlatformWayland();
 
     static QString version();
     Q_INVOKABLE static bool hasYoutubeDl();
@@ -115,6 +121,7 @@ private:
     QString m_systemDefaultStyle;
     QQmlApplicationEngine *m_qmlEngine{nullptr};
     std::unique_ptr<ApplicationEventFilter> m_appEventFilter;
+    std::unique_ptr<QProcess> m_ytdlpProcess;
 };
 
 #endif // APPLICATION_H
